# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

import types

__config__ = pulumi.Config('ns1')


class _ExportableConfig(types.ModuleType):
    @property
    def apikey(self) -> Optional[str]:
        """
        The ns1 API key (required)
        """
        return __config__.get('apikey')

    @property
    def enable_ddi(self) -> Optional[bool]:
        """
        Deprecated, no longer in use
        """
        return __config__.get_bool('enableDdi')

    @property
    def endpoint(self) -> Optional[str]:
        """
        URL prefix (including version) for API calls
        """
        return __config__.get('endpoint')

    @property
    def ignore_ssl(self) -> Optional[bool]:
        """
        Don't validate server SSL/TLS certificate
        """
        return __config__.get_bool('ignoreSsl')

    @property
    def rate_limit_parallelism(self) -> Optional[int]:
        """
        Tune response to rate limits, see docs
        """
        return __config__.get_int('rateLimitParallelism')

    @property
    def retry_max(self) -> Optional[int]:
        """
        Maximum retries for 50x errors (-1 to disable)
        """
        return __config__.get_int('retryMax')

    @property
    def user_agent(self) -> Optional[str]:
        """
        User-Agent string to use in NS1 API requests
        """
        return __config__.get('userAgent')

